==> owncloud-8.2.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files_sharing/l10n/de_DE.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Das Server-zu-Server-Teilen ist auf diesem Server nicht aktiviert",
    "The mountpoint name contains invalid characters." : "Der Name des Einhängepunktes enthält ungültige Zeichen.",
    "Invalid or untrusted SSL certificate" : "Ungültiges oder nicht vertrauenswürdiges SSL-Zertifikat",
    "Could not authenticate to remote share, password might be wrong" : "Die Authentifizierung an der entfernten Freigabe konnte nicht erfolgen, das Passwort könnte falsch sein",
    "Storage not valid" : "Speicher ungültig",
    "Couldn't add remote share" : "Entfernte Freigabe kann nicht hinzugefügt werden",
    "Shared with you" : "Mit Ihnen geteilt",
    "Shared with others" : "Von Ihnen geteilt",
    "Shared by link" : "Geteilt über einen Link",
    "Nothing shared with you yet" : "Bis jetzt wurde nichts mit Ihnen geteilt",
    "Files and folders others share with you will show up here" : "Mit Ihnen geteilte Dateien und Ordner anderer werden hier erscheinen",
    "Nothing shared yet" : "Noch nichts geteilt",
    "Files and folders you share will show up here" : "Dateien und Ordner, die Sie teilen, werden hier erscheinen",
    "No shared links" : "Keine geteilten Links",
    "Files and folders you share by link will show up here" : "Dateien und Ordner, die Sie per Link teilen, werden hier erscheinen",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Möchten Sie die entfernte Freigabe {name} von {owner}@{remote} hinzufügen?",
    "Remote share" : "Entfernte Freigabe",
    "Remote share password" : "Passwort für die entfernte Freigabe",
    "Cancel" : "Abbrechen",
    "Add remote share" : "Entfernte Freigabe hinzufügen",
    "You can upload into this folder" : "Sie können in diesen Ordner hochladen",
    "No ownCloud installation (7 or higher) found at {remote}" : "Keine OwnCloud-Installation (7 oder höher) auf {remote} gefunden",
    "Invalid ownCloud url" : "Ungültige OwnCloud-Adresse",
    "Shared by" : "Geteilt von",
    "Sharing" : "Teilen",
    "A file or folder has been <strong>shared</strong>" : "Eine Datei oder ein Ordner wurde <strong>geteilt</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Eine Datei oder ein Ordner wurde von <strong>einem anderen Server</strong> geteilt",
    "A public shared file or folder was <strong>downloaded</strong>" : "Eine öffentliche geteilte Datei oder ein öffentlicher geteilter Ordner wurde <strong>heruntergeladen</strong>",
    "You received a new remote share %2$s from %1$s" : "Sie haben eine neue Remotefreigabe %2$s von %1$s erhalten",
    "You received a new remote share from %s" : "Sie haben eine neue Remotefreigabe von %s erhalten",
    "%1$s accepted remote share %2$s" : "%1$s hat die Remotefreigabe von %2$s akzeptiert",
    "%1$s declined remote share %2$s" : "%1$s hat die Remotefreigabe von %2$s abgelehnt",
    "%1$s unshared %2$s from you" : "%1$s hat die Freigabe von %2$s für Sie entfernt",
    "Public shared folder %1$s was downloaded" : "Der öffentliche geteilte Ordner %1$s wurde heruntergeladen",
    "Public shared file %1$s was downloaded" : "Die öffentliche geteilte Datei %1$s wurde heruntergeladen",
    "You shared %1$s with %2$s" : "Sie haben %1$s mit %2$s geteilt",
    "You shared %1$s with group %2$s" : "Sie haben %1$s mit der Gruppe %2$s geteilt",
    "%2$s shared %1$s with you" : "%2$s hat %1$s mit Ihnen geteilt",
    "You shared %1$s via link" : "Sie haben %1$s über einen Link geteilt",
    "Shares" : "Geteiltes",
    "Accept" : "Akzeptieren",
    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "Teilen Sie mit mir über meine #ownCloud Federated-Cloud-ID, siehe %s",
    "Share with me through my #ownCloud Federated Cloud ID" : "Teilen Sie mit mir über meine #ownCloud Federated-Cloud-ID",
    "This share is password-protected" : "Diese Freigabe ist durch ein Passwort geschützt",
    "The password is wrong. Try again." : "Das Passwort ist falsch. Bitte versuchen Sie es erneut.",
    "Password" : "Passwort",
    "No entries found in this folder" : "Keine Einträge in diesem Ordner gefunden",
    "Name" : "Name",
    "Share time" : "Zeitpunkt der Freigabe",
    "Sorry, this link doesn’t seem to work anymore." : "Entschuldigung, dieser Link scheint nicht mehr zu funktionieren.",
    "Reasons might be:" : "Gründe könnten sein:",
    "the item was removed" : "Das Element wurde entfernt",
    "the link expired" : "Der Link ist abgelaufen",
    "sharing is disabled" : "Teilen ist deaktiviert",
    "For more info, please ask the person who sent this link." : "Um nähere Informationen zu erhalten, wenden Sie sich bitte an die Person, die Ihnen diesen Link geschickt hat.",
    "Add to your ownCloud" : "Zu Ihrer ownCloud hinzufügen",
    "Download" : "Herunterladen",
    "Download %s" : "Download %s",
    "Direct link" : "Direkte Verlinkung",
    "Federated Cloud Sharing" : "Federated-Cloud-Sharing",
    "Open documentation" : "Dokumentation öffnen",
    "Allow users on this server to send shares to other servers" : "Benutzern auf diesem Server das Senden von Freigaben an andere Server erlauben",
    "Allow users on this server to receive shares from other servers" : "Benutzern auf diesem Server das Empfangen von Freigaben von anderen Servern erlauben",
    "Federated Cloud" : "Federated Cloud",
    "Your Federated Cloud ID:" : "Ihre Federated-Cloud-ID:",
    "Share it:" : "Zum Teilen:",
    "Share with me via ownCloud" : "Teilen Sie mit mir über ownCloud",
    "HTML Code:" : "HTML-Code:"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-8.2.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files_sharing/l10n/de_DE.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Das Server-zu-Server-Teilen ist auf diesem Server nicht aktiviert",
    "The mountpoint name contains invalid characters." : "Der Name des Einhängepunktes enthält ungültige Zeichen.",
    "Invalid or untrusted SSL certificate" : "Ungültiges oder nicht vertrauenswürdiges SSL-Zertifikat",
    "Could not authenticate to remote share, password might be wrong" : "Die Authentifizierung an der entfernten Freigabe konnte nicht erfolgen, das Passwort könnte falsch sein",
    "Storage not valid" : "Speicher ungültig",
    "Couldn't add remote share" : "Entfernte Freigabe kann nicht hinzugefügt werden",
    "Shared with you" : "Mit Ihnen geteilt",
    "Shared with others" : "Von Ihnen geteilt",
    "Shared by link" : "Geteilt über einen Link",
    "Nothing shared with you yet" : "Bis jetzt wurde nichts mit Ihnen geteilt",
    "Files and folders others share with you will show up here" : "Mit Ihnen geteilte Dateien und Ordner anderer werden hier erscheinen",
    "Nothing shared yet" : "Noch nichts geteilt",
    "Files and folders you share will show up here" : "Dateien und Ordner, die Sie teilen, werden hier erscheinen",
    "No shared links" : "Keine geteilten Links",
    "Files and folders you share by link will show up here" : "Dateien und Ordner, die Sie per Link teilen, werden hier erscheinen",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Möchten Sie die entfernte Freigabe {name} von {owner}@{remote} hinzufügen?",
    "Remote share" : "Entfernte Freigabe",
    "Remote share password" : "Passwort für die entfernte Freigabe",
    "Cancel" : "Abbrechen",
    "Add remote share" : "Entfernte Freigabe hinzufügen",
    "You can upload into this folder" : "Sie können in diesen Ordner hochladen",
    "No ownCloud installation (7 or higher) found at {remote}" : "Keine OwnCloud-Installation (7 oder höher) auf {remote} gefunden",
    "Invalid ownCloud url" : "Ungültige OwnCloud-Adresse",
    "Shared by" : "Geteilt von",
    "Sharing" : "Teilen",
    "A file or folder has been <strong>shared</strong>" : "Eine Datei oder ein Ordner wurde <strong>geteilt</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Eine Datei oder ein Ordner wurde von <strong>einem anderen Server</strong> geteilt",
    "A public shared file or folder was <strong>downloaded</strong>" : "Eine öffentliche geteilte Datei oder ein öffentlicher geteilter Ordner wurde <strong>heruntergeladen</strong>",
    "You received a new remote share %2$s from %1$s" : "Sie haben eine neue Remotefreigabe %2$s von %1$s erhalten",
    "You received a new remote share from %s" : "Sie haben eine neue Remotefreigabe von %s erhalten",
    "%1$s accepted remote share %2$s" : "%1$s hat die Remotefreigabe von %2$s akzeptiert",
    "%1$s declined remote share %2$s" : "%1$s hat die Remotefreigabe von %2$s abgelehnt",
    "%1$s unshared %2$s from you" : "%1$s hat die Freigabe von %2$s für Sie entfernt",
    "Public shared folder %1$s was downloaded" : "Der öffentliche geteilte Ordner %1$s wurde heruntergeladen",
    "Public shared file %1$s was downloaded" : "Die öffentliche geteilte Datei %1$s wurde heruntergeladen",
    "You shared %1$s with %2$s" : "Sie haben %1$s mit %2$s geteilt",
    "You shared %1$s with group %2$s" : "Sie haben %1$s mit der Gruppe %2$s geteilt",
    "%2$s shared %1$s with you" : "%2$s hat %1$s mit Ihnen geteilt",
    "You shared %1$s via link" : "Sie haben %1$s über einen Link geteilt",
    "Shares" : "Geteiltes",
    "Accept" : "Akzeptieren",
    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "Teilen Sie mit mir über meine #ownCloud Federated-Cloud-ID, siehe %s",
    "Share with me through my #ownCloud Federated Cloud ID" : "Teilen Sie mit mir über meine #ownCloud Federated-Cloud-ID",
    "This share is password-protected" : "Diese Freigabe ist durch ein Passwort geschützt",
    "The password is wrong. Try again." : "Das Passwort ist falsch. Bitte versuchen Sie es erneut.",
    "Password" : "Passwort",
    "No entries found in this folder" : "Keine Einträge in diesem Ordner gefunden",
    "Name" : "Name",
    "Share time" : "Freigabezeitpunkt",
    "Sorry, this link doesn’t seem to work anymore." : "Entschuldigung, dieser Link scheint nicht mehr zu funktionieren.",
    "Reasons might be:" : "Gründe könnten sein:",
    "the item was removed" : "Das Element wurde entfernt",
    "the link expired" : "Der Link ist abgelaufen",
    "sharing is disabled" : "Teilen ist deaktiviert",
    "For more info, please ask the person who sent this link." : "Um nähere Informationen zu erhalten, wenden Sie sich bitte an die Person, die Ihnen diesen Link geschickt hat.",
    "Add to your ownCloud" : "Zu Ihrer ownCloud hinzufügen",
    "Download" : "Herunterladen",
    "Download %s" : "Download %s",
    "Direct link" : "Direkte Verlinkung",
    "Federated Cloud Sharing" : "Federated-Cloud-Sharing",
    "Open documentation" : "Dokumentation öffnen",
    "Allow users on this server to send shares to other servers" : "Benutzern auf diesem Server das Senden von Freigaben an andere Server erlauben",
    "Allow users on this server to receive shares from other servers" : "Benutzern auf diesem Server das Empfangen von Freigaben von anderen Servern erlauben",
    "Federated Cloud" : "Federated Cloud",
    "Your Federated Cloud ID:" : "Ihre Federated-Cloud-ID:",
    "Share it:" : "Zum Teilen:",
    "Share with me via ownCloud" : "Teilen Sie mit mir über ownCloud",
    "HTML Code:" : "HTML-Code:"
},
"nplurals=2; plural=(n != 1);");
